Crate kcr_notification_toolkit_fluxcd_io

Crate kcr_notification_toolkit_fluxcd_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the notification.toolkit.fluxcd.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

notification.toolkit.fluxcd.io/v1

  • Receiver

notification.toolkit.fluxcd.io/v1beta1

  • Alert
  • Provider
  • Receiver

notification.toolkit.fluxcd.io/v1beta2

  • Alert
  • Provider
  • Receiver

notification.toolkit.fluxcd.io/v1beta3

  • Alert
  • Provider

Modules

v1
v1beta1
v1beta2
v1beta3