This crate contains kube-rs compatible bindings for Kubernetes custom resources for the notification.toolkit.fluxcd.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
notification.toolkit.fluxcd.io/v1
Receiver
notification.toolkit.fluxcd.io/v1beta1
AlertProviderReceiver
notification.toolkit.fluxcd.io/v1beta2
AlertProviderReceiver
notification.toolkit.fluxcd.io/v1beta3
AlertProvider